@@ -14,7 +14,7 @@
 
 import sys
 
-VERSION = (5, 1, 1)
+VERSION = (5, 2, 0)
 __version__ = ".".join([str(s) for s in VERSION])
 
 __title__ = "platformio"
@@ -50,10 +50,10 @@ __core_packages__ = {
     "contrib-piohome": "~3.3.4",
     "contrib-pysite": "~2.%d%d.0" % (sys.version_info.major, sys.version_info.minor),
     "tool-unity": "~1.20500.0",
-    "tool-scons": "~2.20501.7" if sys.version_info.major == 2 else "~4.40100.2",
-    "tool-cppcheck": "~1.230.0",
-    "tool-clangtidy": "~1.100000.0",
-    "tool-pvs-studio": "~7.11.0",
+    "tool-scons": "~4.40200.0",
+    "tool-cppcheck": "~1.250.0",
+    "tool-clangtidy": "~1.120001.0",
+    "tool-pvs-studio": "~7.14.0",
 }
 
 __check_internet_hosts__ = [
