@@ -28,7 +28,6 @@ from platformio.commands.device import helpers as device_helpers
 from platformio.commands.device.command import device_monitor as cmd_device_monitor
 from platformio.commands.run.command import cli as cmd_run
 from platformio.commands.test.command import cli as cmd_test
-from platformio.compat import ensure_python3
 from platformio.package.manager.core import inject_contrib_pysite
 from platformio.project.exception import NotPlatformIOProjectError
 
@@ -37,7 +36,6 @@ from platformio.project.exception import NotPlatformIOProjectError
 @click.option("-a", "--agent", multiple=True)
 @click.pass_context
 def cli(ctx, agent):
-    assert ensure_python3()
     ctx.obj = agent
     inject_contrib_pysite(verify_openssl=True)
 
@@ -352,7 +350,7 @@ def device_monitor(ctx, agents, **kwargs):
             sleep(0.1)
         if not t.is_alive():
             return
-        with open(sock_file) as fp:
+        with open(sock_file, encoding="utf8") as fp:
             kwargs["port"] = fp.read()
         ctx.invoke(cmd_device_monitor, **kwargs)
         t.join(2)
